@@ -64,7 +64,7 @@ read.dta <- function(file, convert.dates = TRUE,
         as.POSIXct((x+0.1)/1000, origin = "1960-01-01") # avoid rounding down
 
     convert_dt_C <- function(x) {
-        ls <- .leap.seconds + seq_along(.leap.seconds)
+        ls <- .leap.seconds + seq_along(.leap.seconds) + 315619200
         z <- (x+0.1)/1000 # avoid rounding down
         z <- z - rowSums(outer(z, ls, ">="))
         as.POSIXct(z, origin = "1960-01-01")
